#!/usr/bin/env python
#   This file is part of nexdatas - Tango Server for NeXus data writer
#
#    Copyright (C) 2012-2017 DESY, Jan Kotanski <jkotan@mail.desy.de>
#
#    nexdatas is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    nexdatas is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with nexdatas.  If not, see <http://www.gnu.org/licenses/>.
#

"""  nexus xml templates for P10"""

__version__ = "1.0.0"

#: (:obj:`dict` <:obj:`str` , :obj:`dict` <:obj:`str` , :obj:`str` > >)
#:     standatd component template variables
#:     and its [default value, doc string]
standardComponentVariables = {
    'bdu': {
        'lat1': {
            'default': None,
            'doc': "horizontal translation of the first crystal"
            " (datasource)"
        },
        'roll2': {
            'default': None,
            'doc': "chi angle position of the second crystal (datasource)"
        },
        'yaw2': {
            'default': None,
            'doc': "horizontal rotation of the second crystal"
            " (datasource)"
        },
        'lin2': {
            'default': None,
            'doc': "along the beam translation of the second crystal"
            " (datasource)"
        },
        'yaw': {
            'default': None,
            'doc': "horizontal rotation of the bdu stage"
            " (datasource)"
        },
        'x': {
            'default': None,
            'doc': "horizontal translation of the bdu stage"
            " (datasource)"
        },
        'y': {
            'default': None,
            'doc': "vertical translation of the bdu stage"
            " (datasource)"
        },
    },
    'insstage': {
        'topdependson': {
            'default': 'pitch',
            'doc': "top depends_on e.g. x (string)"
        },
        'ydependson': {
            'default': 'z',
            'doc': "z depends_on e.g. '' (string)"
        },
        'x': {
            'default': None,
            'doc': "horizontal translation of instrument stage"
            " (datasource)"
        },
        'y': {
            'default': None,
            'doc': "vertical translation of instrument stage"
            " (datasource)"
        },
        'z': {
            'default': None,
            'doc': "along the beam translation of instrument stage"
            " (datasource)"
        },
        'pitch': {
            'default': None,
            'doc': "theta rotation of instrument stage"
            " (datasource)"
        },
        'yaw': {
            'default': None,
            'doc': "horizontal rotation of instrument stage"
            " (datasource)"
        },
    },
    'slitstage': {
        'slitname': {
            'default': 'slit',
            'doc': "slit group name (string)"
        },
        'dependson': {
            'default': 'x',
            'doc': "pitch depends_on  field (string)"
        },
        'x': {
            'default': None,
            'doc': "horizontal position (datasource)"
        },
        'y': {
            'default': None,
            'doc': "vertical position (datasource)"
        },
        'z': {
            'default': None,
            'doc': "linear (along the beam) position (datasource)"
        },
    },
    'laser': {
        'z': {
            'default': None,
            'doc': "linear (along the beam) position (datasource)"
        },
        'pitch': {
            'default': None,
            'doc': "theta angle position (datasource)"
        },
    },
    'twotheta': {
        'twotheta': {
            'default': None,
            'doc': "two theta angle position of xpcs (datasource)"
        },
        'detname': {
            'default': 'detector',
            'doc': "detector group name (string)"
        },
    },
    'diffractometer': {
        'sname': {
            'default': 'sample',
            'doc': "sample group name (string)"
        },
        'x': {
            'default': None,
            'doc': "horizontal position of the diffractometer table (datasource)"
        },
        'height1': {
            'default': None,
            'doc': "first vertical position of the diffractometer table (datasource)"
        },
        'height2': {
            'default': None,
            'doc': "second vertical position of the diffractometer table (datasource)"
        },
        'height': {
            'default': None,
            'doc': "vertical position of the diffractometer table (datasource)"
        },
        'gamma': {
            'default': None,
            'doc': "gamma angle of the diffractometer circles (datasource)"
        },
        'delta': {
            'default': None,
            'doc': "delta angle of the diffractometer circles (datasource)"
        },
        'mu': {
            'default': None,
            'doc': "mu angle of the diffractometer sample circles (datasource)"
        },
        'chi': {
            'default': None,
            'doc': "chi angle of the diffractometer sample circles (datasource)"
        },
        'phi': {
            'default': None,
            'doc': "phi angle of the diffractometer sample circles (datasource)"
        },
        'omega': {
            'default': None,
            'doc': "omega angle of the diffractometer sample circles (datasource)"
        },
    },
    'opticstable': {
        'grouptype': {
            'default': 'NXcollection',
            'doc': "group type (string)"
        },
        'postfix': {
            'default': '',
            'doc': "coordinate postfix (string)"
        },
        'y1': {
            'default': None,
            'doc': "first height of sample table (datasource)"
        },
        'y2': {
            'default': None,
            'doc': "second height of sampl etable (datasource)"
        },
        'y3': {
            'default': None,
            'doc': "third height of sample table (datasource)"
        },
        'x1': {
            'default': None,
            'doc': "first horizontal translation of sample table (datasource)"
        },
        'x2': {
            'default': None,
            'doc': "second horizontal translation of sample table (datasource)"
        },
        'yaw': {
            'default': None,
            'doc': "phi angle position of sample table (datasource)"
        },
        'pitch': {
            'default': None,
            'doc': "theta angle position of sample table (datasource)"
        },
        'roll': {
            'default': None,
            'doc': "chi angle position of sample table (datasource)"
        },
        'x': {
            'default': None,
            'doc': "horizontal translation of sample table (datasource)"
        },
        'y': {
            'default': None,
            'doc': "height of sample table (datasource)"
        },
    },
    'lenshexapod': {
        'yawdependson': {
            'default': 'roll',
            'doc': "yaw depends_on field .e.g pitch (string)"
        },
        'x': {
            'default': None,
            'doc': "horizontal position (datasource)"
        },
        'y': {
            'default': None,
            'doc': "vertical position (datasource)"
        },
        'z': {
            'default': None,
            'doc': "linear (along the beam) position (datasource)"
        },
        'pivotx': {
            'default': None,
            'doc': "horizontal pivot position (datasource)"
        },
        'pivoty': {
            'default': None,
            'doc': "vertical pivot position (datasource)"
        },
        'pivotz': {
            'default': None,
            'doc': "linear (along the beam) pivot position (datasource)"
        },
        'pitch': {
            'default': None,
            'doc': "theta angle (pitch) position (datasource)"
        },
        'yaw': {
            'default': None,
            'doc': "phi angle (yaw) position (datasource)"
        },
        'roll': {
            'default': None,
            'doc': "chi angle (roll) position of mirror1 (datasource)"
        },
    },
    'shutterstage': {
        'y': {
            'default': None,
            'doc': "vertical position of shutter (datasource)"
        },
        'shname': {
            'default': 'shutter',
            'doc': "shutter group name (string)"
        },
    },
    'sampletable': {
        'sname': {
            'default': 'sample',
            'doc': "sample group name (string)"
        },
        'postfix': {
            'default': '',
            'doc': "coordinate postfix (string)"
        },
        'pitchdependson': {
            'default': 'roll',
            'doc': "pitch depends_on  field (string)"
        },
        'y1': {
            'default': None,
            'doc': "first height of sample table (datasource)"
        },
        'y2': {
            'default': None,
            'doc': "second height of sample table (datasource)"
        },
        'y3': {
            'default': None,
            'doc': "third height of sample table (datasource)"
        },
        'x1': {
            'default': None,
            'doc': "first horizontal translation of sample table (datasource)"
        },
        'x2': {
            'default': None,
            'doc': "second horizontal translation of sample table (datasource)"
        },
        'yaw': {
            'default': None,
            'doc': "phi angle position of sample table (datasource)"
        },
        'pitch': {
            'default': None,
            'doc': "theta angle position of sample table (datasource)"
        },
        'roll': {
            'default': None,
            'doc': "chi angle position of sample table (datasource)"
        },
        'x': {
            'default': None,
            'doc': "horizontal translation of sample table (datasource)"
        },
        'y': {
            'default': None,
            'doc': "height of sample table (datasource)"
        },
    },
    'samplestage': {
        'sname': {
            'default': 'sample',
            'doc': "sample group name (string)"
        },
        'pitchdependson': {
            'default': 'roll',
            'doc': "pitch depends_on  field (string)"
        },
        'postfix': {
            'default': '',
            'doc': "coordinate postfix (string)"
        },
        'yaw': {
            'default': None,
            'doc': "phi angle position of sample stage (datasource)"
        },
        'pitch': {
            'default': None,
            'doc': "theta angle position of sample stage (datasource)"
        },
        'roll': {
            'default': None,
            'doc': "chi angle position of sample stage (datasource)"
        },
        'x': {
            'default': None,
            'doc': "horizontal translation of sample stage (datasource)"
        },
        'y': {
            'default': None,
            'doc': "height of sample stage (datasource)"
        },
        'z': {
            'default': None,
            'doc': "along the beam translation of sample stage (datasource)"
        },
    },
    'crl': {
        'v': {
            'default': None,
            'doc': "vertical position of lensbox (datasource)"
        },
        'h': {
            'default': None,
            'doc': "horizontal position of lensbox (datasource)"
        },
        'trans': {
            'default': None,
            'doc': "translation along the beam of lensbox (datasource)"
        },
        'lensposition': {
            'default': None,
            'doc': "position of lenses in lenbox (datasource)"
        },
        'pitch': {
            'default': None,
            'doc': "theta angle position of lensbox (datasource)"
        },
        'yaw': {
            'default': None,
            'doc': "phi angle position of lensbox (datasource)"
        },
    },
    'detstage': {
        'detname': {
            'default': 'detector',
            'doc': "detector group name (string)"
        },
        'grouptype': {
            'default': 'NXdetector',
            'doc': "device group type (string)"
        },
        'dependson': {
            'default': 'yaw',
            'doc': "depends_on  field (string)"
        },
        'yawdependson': {
            'default': 'pitch',
            'doc': "yaw depends_on  field (string)"
        },
        'yaw': {
            'default': None,
            'doc': "phi angle position of detector stage (datasource)"
        },
        'pitch': {
            'default': None,
            'doc': "theta angle position of detector stage (datasource)"
        },
        'roll': {
            'default': None,
            'doc': "chi angle position of detector stage (datasource)"
        },
        'x': {
            'default': None,
            'doc': "horizontal translation of detector stage (datasource)"
        },
        'x2': {
            'default': None,
            'doc': "second horizontal translation of detector stage (datasource)"
        },
        'y': {
            'default': None,
            'doc': "height of detector stage (datasource)"
        },
        'z': {
            'default': None,
            'doc': "along the beam translation of detector stage (datasource)"
        },
    },
    'cryostage': {
        'sname': {
            'default': 'sample',
            'doc': "sample group name (string)"
        },
        'x': {
            'default': None,
            'doc': "horizontal translation of sample cryo"
            " (datasource)"
        },
        'y': {
            'default': None,
            'doc': "vertical translation of sample cryo"
            " (datasource)"
        },
        'z': {
            'default': None,
            'doc': "along the beam translation of sample cryo"
            " (datasource)"
        },
        'distance': {
            'default': None,
            'doc': "distance from the sample of the second cristal in m, e.g. 65.6 (string)"
        },
        'distanceoffset': {
            'default': None,
            'doc': "3-vector distance offset of the first cristal in m, e.g. sample-source offset if the distance is taken from the source (string)"
        },
    },
    'mirrors': {
        'dependson1': {
            'default': 'theta',
            'doc': "depends_on field of mirror1 (string)"
        },
        'dependson2': {
            'default': 'theta',
            'doc': "depends_on field of mirror2 (string)"
        },
        'pitch1': {
            'default': None,
            'doc': "theta angle position of mirror1 (datasource)"
        },
        'x1': {
            'default': None,
            'doc': "horizontal position of mirror1 (datasource)"
        },
        'y1': {
            'default': None,
            'doc': "vertical position of mirror1 (datasource)"
        },
        'gap': {
            'default': None,
            'doc': "horrizontal gap of mirrors (datasource)"
        },
        'pitch2': {
            'default': None,
            'doc': "theta angle position of mirror2 (datasource)"
        },
        'x2': {
            'default': None,
            'doc': "horizontal position of mirror2 (datasource)"
        },
        'y2': {
            'default': None,
            'doc': "vertical position of mirror2 (datasource)"
        },
        'offset': {
            'default': None,
            'doc': "horizontal offset of mirrors (datasource)"
        },
        'x': {
            'default': None,
            'doc': "horizontal position of mirrors (datasource)"
        },
        'y': {
            'default': None,
            'doc': "vertical position of mirrors (datasource)"
        },
    },
    'pointdet': {
        'data': {
            'default': None,
            'doc': "diode data (datasource)"
        },
        'detname': {
            'default': 'detector',
            'doc': "detector group name (string)"
        },
    },
    'girder': {
        'x1': {
            'default': None,
            'doc': "first horizontal position of girder (datasource)"
        },
        'y1': {
            'default': None,
            'doc': "first vertical position of girder (datasource)"
        },
        'x2': {
            'default': None,
            'doc': "second horizontal position of girder (datasource)"
        },
        'y2': {
            'default': None,
            'doc': "second vertical position of girder (datasource)"
        },
        'x': {
            'default': None,
            'doc': "average horizontal position of girder (datasource)"
        },
        'y': {
            'default': None,
            'doc': "average vertical position of girder (datasource)"
        },
    },
}

#: (:obj:`dict` <:obj:`str` , :obj:`list` <:obj:`str`> >)
#:     xml teplate files of modules
standardComponentTemplateFiles = {
    'mirrors': [
        'mirrors.xml',
    ],
    'girder': [
        'girder.xml',
    ],
    'cryostage': [
        'cryostage.xml',
    ],
    'sampletable': [
        'sampletable.xml',
    ],
    'samplestage': [
        'samplestage.xml',
    ],
    'detstage': [
        'detstage.xml',
    ],
    'opticstable': [
        'opticstable.xml',
    ],
    'shutterstage': [
        'shutterstage.xml',
    ],
    'lenshexapod': [
        'lenshexapod.xml',
    ],
    'diffractometer': [
        'diffractometer.xml',
    ],
    'pointdet': [
        'pointdet.xml',
    ],
    'slitstage': [
        'slitstage.xml',
    ],
    'laser': [
        'laser.xml',
    ],
    'insstage': [
        'insstage.xml',
    ],
    'crl': [
        'crl.xml',
    ],
    'bdu': [
        'bdu.xml',
    ],
    'twotheta': [
        'twotheta.xml',
    ],
}

#: (:obj:`dict` <:obj:`str` , :obj:`list` <:obj:`str`> >)
#:     xml template files of modules
moduleTemplateFiles = {
}

#: (:obj:`dict` <:obj:`str` , :obj:`list` <:obj:`str`> >)
#:     important attributes of modules
moduleMultiAttributes = {
}
